
/*-----------------------------------------------------------------------------------------
Modelado del reactor en lazo abierto
 LIBRARY: DEFAULT_LIB
 FILE: Reactor
 CREATION DATE: 02/03/2016
-----------------------------------------------------------------------------------------*/

USE MATH
USE CONTROL


COMPONENT Reactor_Bueno

	DATA --Poner las unidades como las tengo apuntadas en el folio.
	
		REAL Ap=0.5       -- Apertura de la valvula
		--REAL R        					-- El valor de la resistencia
		REAL A=0.3       UNITS "m^2"        -- El area de intercambio de calor, unidades m^2
		REAL V=4.67      UNITS "l"  			-- Volumen del reactor, unidades en l
		REAL Vc=1        UNITS "l"          --Volumen de la camisa
		REAL Cer=4.18    UNITS "Kj/Kg"  			-- Calor especifico, unidades en Kj/Kg
		REAL Tin=10      UNITS "C"				-- Temperatura del caudal que entral al reactor, es la ambiente, unidades C
		REAL Pir=15      UNITS "Bar" 			-- Presion de entrada a la camisa en bar
		REAL Ro=1        UNITS "Kg/l"			   -- Densidad del agua, unidades Kg/l
		REAL G=9.8       UNITS "m/s^2" 			-- Gravedad, unidades m/s^2
		REAL Kl1=0       				-- Constante de perdidas en la tuberia, al no poder medirlo exactamente porque aun no esta montada la planta, al ser un tramo muy pequeo las ponemos despeciables
		REAL Cv=3.57       			-- Constante de la valvula
		REAL Hic=0.08    UNITS "m"   			-- Es la diferencia entre la altura de entrada y la salida del agua en esa linea, unidades m.
		REAL Hcam=0.33   UNITS "m"    			-- Altura de la camisa del reactor, unidades m
		REAL Hsr= 0.10   UNITS "m"   			-- Diferencia entre la salida de agua del reactor a la bomba y el desa gue, unidades m.
		REAL Hreac= 0.12 UNITS "m"   			-- Altura de liquido que hay por encima de la salida a la bomba centrifuga, unidades m
		
		--Para la reaccion quimica hemos cogido la formacion de agua, H2+O2 -> H2O 
		
		REAL E=2420       UNITS "J/mol"				      -- Parametro propio de la reaccion, unidades J/mol
		REAL Inal= 20   UNITS "Kj/mol"  			-- Valor constante, lo que reacciona cada segundo en la reaccion, unidades KJ/mol
		REAL Rr=8.31434  UNITS "J/mol*K"          --Constante universal de los gases, unidades J/(mol*K)
		--E/Rr=3000
		REAL Cai= 0.8   UNITS "mol/l"			-- Concentracion inicial de A en mol/l
		REAL K=1.380		UNITS "s^-1"--Esta constante tiene que estar s^-1.
		REAL Vbp1=1
		REAL Vbp2=3
		
	DECLS
	
		REAL U             			-- Valor del coeficiente de intercambio de calor
		REAL mr        UNITS "Kg"    -- Masa del reactor, unidades Kg.
		REAL mc        UNITS "Kg"    -- Masa de la camisa 
		REAL Wro       UNITS "Kg/min" -- Flujo de Caudal que le entra a la camisa 
		REAL Wr        UNITS "Kg/min"   -- Flujo de caudal que le sale a la camisa
		REAL Fr        UNITS "l/min"  -- Caudal que entra y sale de la camisa, ambos son iguales, unidades l/min
		REAL T=15      UNITS "C" -- Temperatura del reactor, unidades C
		REAL Tr=10     UNITS "C" -- Temperatura de la camisa
 
		REAL Wi        UNITS "Kg/min"  -- Flujo de caudal que entra al reactor de la calle, unidades Kg/min
		REAL Fi        UNITS "l/min"   -- Caudal que entra al reactor de la calle, unidades l/min
		REAL Wres      UNITS "Kg/min"   -- Flujo de caudal que entra desde la resistencia, unidades Kg/min
		REAL Fres      UNITS "l/min"  -- Caudal que entra desde la resistencia, unidades l/min
		REAL Tres      UNITS "C"  -- Temperatura del caudal que entra desde la resistencia, unidades C
		REAL Hb    	  UNITS "l/min"    -- Altura que da la bomba dosificadora, esta la ponemos nosotros
		REAL Qres     UNITS "Kw"   -- Calor producido por las resistencias
		--REAL I      -- Intensidad que enviamos a las resistencias
		REAL Fo       UNITS "l/min"  -- Caudal de salida del reactor, unidades l/min.
		REAL Wo       UNITS "Kg/min"    -- Flujo de caudal de salida del reactor, unidades Kg/min
		REAL Tro      UNITS "C"  -- Temperatura del flujo que sale de la camisa, unidades C
		REAL Q        UNITS "Kw"          -- Calor por conduccion o por conveccion
		REAL Ca=0.05  UNITS "mol/l"   -- Concentracion de a, hemos cogido que el producto a se tranforma en un producto b, unidades mol/l.
		REAL P        UNITS "Kw"    -- Potencia que da la unidad de potencia, unidades en W.
		REAL Vreac                      -- Velocidad de la reaccion
		REAL Mat      UNITS "Kj*C/min"
		REAL Ment     UNITS "Kj*C/min"
		REAL Msal     UNITS "Kj*C/min"
		REAL Tk       UNITS "K"         --Temperatura del reactor en Kelvin
		
				
	DISCRETE
	
	CONTINUOUS
	
		--Ecuacion del coeficiente global de transferencia de calor Preguntar si es necesaria usar?
		U=0.074+1.982*Fr*10
		Tro=10
		Hb=75
		
		--Fo y Fi tienen que ser iguales porque el volumen del reactor es constante
		
	   --Ecuaciones que relacionan el caudal con la altura de las bombas peristalticas
		Fi=Vbp1
		Fo=Fi
		Fres=Vbp2
		-- Formula de calculo de caudal cuando tenemos una valvula 
		Fr=((1/1.16)*((Pir-Ro*G*Hcam-Ro*G*Hic)/(Ro*(Kl1+(1/((Ap**2)*(Cv**2)))))**(1/2)))/3.6
		
		mr=V*Ro               -- Masa del reactor es volumen por densidad
		mc=Vc*Ro              -- Masa de la camisa
		Q=U*A*(T-Tr)          -- Transferencia de calor por conduccion y conveccion, calor que perdemos en el encamisado
				
	--	E=mr*Cer*T            --Energia
		Qres=P				    --I**2*R--Calor producido en la resistencia  --> P=V*I, La v es constante, y la I es la que tenemos que ver que no pase la maxima permitida por la unidad de potencia.
		Wro=Fr*Ro   			 -- Calculo del flujo mxico
		Wr=Wro
		Wi=Fi*Ro
		Wres=Fres*Ro
		Wo=Fo*Ro
		Mat=Wi*Cer*(Tin-T)
		Ment=Wr*Cer*Tr
		Msal=Wro*Cer*Tro
		--Balance de materia a la camisa
		mc*Cer*Tr'=Msal-Ment+Q
		--Balance de materia al reactor
		mr*Cer*T'=Mat-Q+Qres
		
		Tk=T+273
		
		--Ecuacion para el calculo de Tres
		Fres*Ro*Cer*T + Q = Fres*Ro*Cer*Tres           
		
		--Ecuaciones que relacionan el calor de la resistencia con el de una reaccion quimica
		Vreac=V*K*exp(-E/(Rr*Tk))*Ca
		P=Vreac*Inal
		V*Ca'=Wi*Cai- Wi*Ca-Vreac
		--V*K*exp(-E/(Rr*T))*Ca --> Esta es la velocidad de reaccion

END COMPONENT