
/*-----------------------------------------------------------------------------------------
Estructura de control en cascada tipo 1
 LIBRARY: DEFAULT_LIB
 FILE: Reactor
 CREATION DATE: 02/03/2016
-----------------------------------------------------------------------------------------*/

USE MATH
USE CONTROL


COMPONENT Reactor_Bueno_Control_Cascada

	DATA --Poner las unidades como las tengo apuntadas en el folio.
	
		--REAL R        					-- El valor de la resistencia
		             			-- Valor del coeficiente de intercambio de calor, unidades en Kj/m^2C KW ceo que es.
		REAL A=0.3       UNITS "m^2"        -- El area de intercambio de calor, unidades m^2
		REAL V=4.67      UNITS "l"  			-- Volumen del reactor, unidades en l
		REAL Cer=4.18    UNITS "Kj/Kg*K"  			-- Calor especifico, unidades en Kj/Kg
		REAL Tin=10      UNITS "C"				-- Temperatura del caudal que entral al reactor, es la ambiente, unidades C
		REAL Pir=15      UNITS "Bar" 			-- Presion de entrada a la camisa en bar
		REAL Ro=1        UNITS "Kg/l"			   -- Densidad del agua, unidades Kg/l
		REAL G=9.8       UNITS "m/s^2" 			-- Gravedad, unidades m/s^2
		REAL Kl1=0       				-- Constante de perdidas en la tuberia, al no poder medirlo exactamente porque aun no esta montada la planta, al ser un tramo muy pequeo las ponemos despeciables
		REAL Cv=3.57       			-- Constante de la valvula
		REAL Hic=0.08    UNITS "m"   			-- Es la diferencia entre la altura de entrada y la salida del agua en esa linea, unidades m.
		REAL Hcam=0.33   UNITS "m"    			-- Altura de la camisa del reactor, unidades m
		REAL Hsr= 0.10   UNITS "m"   			-- Diferencia entre la salida de agua del reactor a la bomba y el desa gue, unidades m.
		REAL Hreac= 0.12 UNITS "m"   			-- Altura de liquido que hay por encima de la salida a la bomba centrifuga, unidades m
		
		--Para la reaccion quimica hemos cogido la formacion de agua, H2+O2 -> H2O 
		
		REAL E=4840       UNITS "J/mol"				      -- Parametro propio de la reaccion, unidades KJ
		REAL Inal=20   UNITS "Kj/mol"  			-- Valor constante, lo que reacciona cada segundo en la reaccion, unidades KJ/mol
		REAL Rr=8.31434  UNITS "J/mol*K"          --Constante universal de los gases, unidades J/(mol*K)
		--E/Rr=3000
		REAL Cai= 0.8   UNITS "mol/l"			-- Concentracion inicial de A en mol/l, la ponemos al 80%
		REAL K=1.380		UNITS "s^-1"-- unidades s^-1
		--REAL Ap=0.5       -- Apertura de la valvula
	
		REAL k=1
		REAL Ti=10
		REAL k2=-2
		REAL Ti2=0.5
		REAL Tt=2
		REAL Tref=11.8
		REAL Vbp1=1
		REAL Vbp2=3
		REAL Vc=1
	DECLS
	
		--REAL Ap       -- Apertura de la valvula
		REAL U
		REAL mc			UNITS "Kg"
		REAL mr        UNITS "Kg"    -- Masa del reactor, unidades Kg.
		REAL Wro       UNITS "Kg/min" -- Flujo de Caudal que le entra a la camisa 
		REAL Wr        UNITS "Kg/min"   -- Flujo de caudal que le sale a la camisa
		REAL Fr        UNITS "l/min"  -- Caudal que entra y sale de la camisa, ambos son iguales, unidades l/min
		REAL T=15      UNITS "C" -- Temperatura del reactor, unidades C
		REAL Tr=10     UNITS "C" -- Temperatura de la camisa
 
		REAL Wi        UNITS "Kg/min"  -- Flujo de caudal que entra al reactor de la calle, unidades Kg/min
		REAL Fi        UNITS "l/min"   -- Caudal que entra al reactor de la calle, unidades l/min
		REAL Wres      UNITS "Kg/min"   -- Flujo de caudal que entra desde la resistencia, unidades Kg/min
		REAL Fres      UNITS "l/min"  -- Caudal que entra desde la resistencia, unidades l/min
		REAL Tres      UNITS "C"  -- Temperatura del caudal que entra desde la resistencia, unidades C
		REAL Hb    	  UNITS "l/min"    -- Altura que da la bomba dosificadora, esta la ponemos nosotros
		REAL Qres     UNITS "Kw"   -- Calor producido por las resistencias
		--REAL I      -- Intensidad que enviamos a las resistencias
		REAL Fo       UNITS "l/min"  -- Caudal de salida del reactor, unidades l/min.
		REAL Wo       UNITS "Kg/min"    -- Flujo de caudal de salida del reactor, unidades Kg/min
		REAL Tro      UNITS "C"  -- Temperatura del flujo que entra a la camisa, unidades C
		REAL Q        UNITS "Kw"          -- Calor por conduccion o por conveccion
		REAL Ca=0.05  UNITS "mol/l"   -- Concentracion de a, hemos cogido que el producto a se tranforma en un producto b, unidades mol/l.
		REAL P        UNITS "Kw"    -- Potencia que da la unidad de potencia, unidades en W.
		REAL Vreac        -- Velocidad de la reaccion
		REAL Mat      UNITS "Kj*C/min"
		REAL Ment     UNITS "Kj*C/min"
		REAL Msal     UNITS "Kj*C/min"
		REAL Tk       UNITS "K"  --Temperatura del reactor en grados kelvin
		--Primer controlador
		REAL e
		REAL v
		REAL u
		REAL ew
		REAL L1
		--Segundo Controlador
		REAL e2
		REAL v2
		REAL u2
		REAL ew2
		REAL L2
		--Tercer Controlador
		--REAL e3
		--REAL v3
		--REAL u3
		--REAL ew3
		--REAL L3
		
				
	DISCRETE
	
	CONTINUOUS
	
		--Ecuacion del coeficiente global de transferencia de calor
		U=0.074+1.982*Fr*10
		Tro=10

		Hb=75
	
		
		--"Fo y Fi tienen que ser iguales porque el volumen del reactor es constante"

		Fo=Fi -- Sacar de la tabla al 75 % sabes que es fijo
	   --Ecuaciones que relacionan el caudal con la altura de las bombas peristalticas
		Fi=Vbp1
		Fres=Vbp2
		-- Formula de calculo de caudal cuando tenemos una valvula 
		--Fr=((1/1.16)*((Pir-Ro*G*Hcam-Ro*G*Hic)/(Ro*(Kl1+(1/((Ap**2)*(Cv**2)))))**(1/2)))/3.6

		mr=V*Ro               -- Masa del reactor es volumen por densidad
		mc=Vc*Ro
		Q=U*A*(T-Tr)          -- Transferencia de calor por conduccion y conveccion, calor que perdemos en el encamisado
		
		--Ecuacion para el calculo de Tres
		Fres*Ro*Cer*T + Q = Fres*Ro*Cer*Tres 
		
	--	E=mr*Cer*T            --Energia
		Qres=P				    --I**2*R--Calor producido en la resistencia  --> P=V*I, La v es constante, y la I es la que tenemos que ver que no pase la maxima permitida por la unidad de potencia.
		Wro=Fr*Ro   			 -- Calculo del flujo mxico
		Wr=Wro
		Wi=Fi*Ro
		Wres=Fres*Ro
		Wo=Fo*Ro
		Mat=Wi*Cer*(Tin-T)
		Ment=Wr*Cer*Tr
		Msal=Wro*Cer*Tro
		--Balance de materia a la camisa
		mc*Cer*Tr'=Msal-Ment+Q
		--Balance de materia al reactor
		mr*Cer*T'=Mat-Q+Qres
		
		Tk=T+273
		
		--Ecuaciones que relacionan el calor de la resistencia con el de una reaccion quimica
		Vreac=V*K*exp(-E/(Rr*Tk))*Ca
		P=Vreac*Inal
		V*Ca'=Wi*Cai- Wi*Ca-Vreac
		--V*K*exp(-E/(Rr*T))*Ca --> Esta es la velocidad de reaccion
		
		--Mi Controlador
		
		--Control Temperatura Camisa
		e=Tref-T
		L1=k*e+v
		-- Tiene que dar un valor entre 10 y 45, porque es la consigna para la temeperatura de la camisa
		--Este controlador tiene ganancia positiva si queremos aumentar la temperatura la salida tiene que ser mayor
		u= ZONE ( L1 < 45 AND L1 >10 ) L1
		   ZONE ( L1 >= 45) 45
			OTHERS 10
		--u=k*e+v 
		v'=(k*e/Ti)+ew/Tt
		ew=u-L1 -- Termino para evitar el Antiwindup
		--Control Temperatura reactor
		--Este controlador tiene ganancia negativa, si queremos incrementar la temperatura tenemos que disminuir el caudal de referencia al segundo controlador
		e2=u-Tr --Tr es la temperatura de salida del flujo de la camisa que suponemos que sera igual al que hay en la camisa
		L2=k2*e2+v2
		-- No puede dar un valor mayor que 10 y menor que 0, porque es la consigna para el caudal
		u2= ZONE ( L2 < 9 AND L2 >0 ) L2
		    ZONE ( L2 >= 9) 9
			 OTHERS 0
		--u2=k2*e2+v2
		v2'=(k2*e2/Ti2)+ew2/Tt
		ew2=u2-L2
		--Control de caudal valvula de entrada agua a la camisa
		--Este controlador tiene ganancia positiva si queremos aumentar el caudal la salida tiene que ser mas grande 
		Fr=u2
		--e3=u2-Fr
		--L3=k3*e3+v3
		-- Tiene que dar un valor entre 0 y 1 puesto que su salida es la variable manipulada
		--u3= ZONE ( L3 < 1 AND L3 >0 ) L3
		  -- ZONE ( L3 >= 1) 1
			--OTHERS 0
		
		--v3'=(k3*e3/Ti3)+ew3/Tt
		--ew3=u3A-L3 -- Termino para evitar el Antiwindup
		--Ap=u3

END COMPONENT